@@ -1,6 +1,7 @@
 import json
 from allosaurus.lm.mask import *
 
+
 class Inventory:
 
     def __init__(self, model_path):
@@ -9,6 +10,7 @@ class Inventory:
 
         self.lang_names = []
         self.lang_ids = []
+        self.glotto_ids = []
 
         self.lang2phonefile = dict()
 
@@ -21,20 +23,30 @@ class Inventory:
         for lang in langs:
 
             lang_name = lang['LanguageName']
-            lang_id = lang['ISO6393']
+            iso_id = lang['ISO6393']
+            glotto_id = lang['GlottoCode']
             phone_text = lang['phonelists']
+
             self.lang_names.append(lang_name.lower())
-            self.lang_ids.append(lang_id.lower())
+            self.lang_ids.append(iso_id.lower())
+            self.glotto_ids.append(glotto_id)
 
-            self.lang2phonefile[lang_id.lower()] = phone_text
+            # register both iso_id and glottocode id
+            self.lang2phonefile[iso_id.lower()] = phone_text
+            self.lang2phonefile[glotto_id.lower()] = phone_text
 
-
-    def get_mask(self, lang_id=None, approximation=False):
+    def get_unit(self, lang_id):
 
         assert lang_id in self.lang2phonefile, "Language "+lang_id+" is not available !"
 
         unit_file = self.model_path / 'inventory' / self.lang2phonefile[lang_id]
-
         target_unit = read_unit(str(unit_file))
 
+        return target_unit
+
+
+    def get_mask(self, lang_id=None, approximation=False):
+
+        target_unit = self.get_unit(lang_id)
+
         return UnitMask(self.unit, target_unit, approximation)
\ No newline at end of file
